Index: res/res_agi.c
===================================================================
--- res/res_agi.c	(revision 34129)
+++ res/res_agi.c	(working copy)
@@ -222,6 +222,7 @@
 	}
 
 	/* If we have a script parameter, relay it to the fastagi server */
+	/* Script parameters take the form of: AGI(agi://my.example.com/?extension=${EXTEN}) */
 	if (!ast_strlen_zero(script))
 		fdprintf(s, "agi_network_script: %s\n", script);
 
@@ -328,6 +329,7 @@
 			close(x);
 
 		/* Execute script */
+		/* XXX argv should be depretiated in favor of passing agi_argX paramaters */
 		execv(script, argv);
 		/* Can't use ast_log since FD's are closed */
 		fprintf(stdout, "verbose \"Failed to execute '%s': %s\" 2\n", script, strerror(errno));
@@ -353,8 +355,10 @@
 		
 }
 
-static void setup_env(struct ast_channel *chan, char *request, int fd, int enhanced)
+static void setup_env(struct ast_channel *chan, char *request, int fd, int enhanced, int argc, char *argv[])
 {
+	int count;
+
 	/* Print initial environment, with agi_request always being the first
 	   thing */
 	fdprintf(fd, "agi_request: %s\n", request);
@@ -382,6 +386,11 @@
 	/* User information */
 	fdprintf(fd, "agi_accountcode: %s\n", chan->accountcode ? chan->accountcode : "");
     
+	/* Send any parameters to the fastagi server that have been passed via the agi application */
+	/* Agi application paramaters take the form of: AGI(/path/to/example/script|${EXTEN}) */
+	for(count = 1; count < argc; count++)
+		fdprintf(fd, "agi_arg_%d: %s\n", count, argv[count]);
+
 	/* End with empty return */
 	fdprintf(fd, "\n");
 }
@@ -1813,7 +1822,7 @@
 	return 0;
 }
 #define RETRY	3
-static enum agi_result run_agi(struct ast_channel *chan, char *request, AGI *agi, int pid, int *status, int dead)
+static enum agi_result run_agi(struct ast_channel *chan, char *request, AGI *agi, int pid, int *status, int dead, int argc, char *argv[])
 {
 	struct ast_channel *c;
 	int outfd;
@@ -1834,7 +1843,7 @@
 		return AGI_RESULT_FAILURE;
 	}
 	setlinebuf(readf);
-	setup_env(chan, request, agi->fd, (agi->audio > -1));
+	setup_env(chan, request, agi->fd, (agi->audio > -1), argc, argv);
 	for (;;) {
 		ms = -1;
 		c = ast_waitfor_nandfds(&chan, dead ? 0 : 1, &agi->ctrl, 1, NULL, &outfd, &ms);
@@ -2016,7 +2025,7 @@
 		agi.fd = fds[1];
 		agi.ctrl = fds[0];
 		agi.audio = efd;
-		res = run_agi(chan, argv[0], &agi, pid, &status, dead);
+		res = run_agi(chan, argv[0], &agi, pid, &status, dead, argc, argv);
 		/* If the fork'd process returns non-zero, set AGISTATUS to FAILURE */
 		if (res == AGI_RESULT_SUCCESS && status)
 			res = AGI_RESULT_FAILURE;
